==> deepin-log-viewer_5.9.7+ds1.orig.tar.xz: deepin-log-viewer-5.9.7/translations/deepin-log-viewer_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Mostra al gestor de fitxers</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Esborra el registre</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Actualitza</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Segur que voleu esborrar el registre?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmeu-ho</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Tots</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Avui</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 dies</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 setmana</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 mes</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 mesos</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Exporta</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exporta</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Tots</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Emergència</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alerta</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Crític</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Avís</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Observació</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informació</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Depuració</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Entrada</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Arrencada</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Molt crític</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Traça</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>S&apos;exporta...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Exportació correcta</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Ha fallat l&apos;exportació.</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Exporta el fitxer</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Període:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Nivell:</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Llista d&apos;aplicacions:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Estat:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Tipus d&apos;esdeveniment:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Usuari:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Acció:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nom d&apos;usuari:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Registre d&apos;arrencada</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Historial d&apos;aturada</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Historial d&apos;entrada</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Avís</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Depuració</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informació</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Emergència</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alerta</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Crític</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Observació</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Traça</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Molt crític</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>El fitxer de registre és buit.</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Visor de registres</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>El Visor de registres és una eina útil per veure els registres del sistema.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>No hi ha resultats de cerca</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Nivell</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Procés</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Dia i hora</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informació</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuari</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Font</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Acció</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estat</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Tipus d&apos;esdeveniment</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;usuari</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nivell:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Procés:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Dia i hora:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Informació:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Nul</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Usuari:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Data i hora</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Registre del sistema</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Registre del nucli</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Registre d&apos;arrencada</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Registre del dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Registre de Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Registre del Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Registre d&apos;aplicacions</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Esdeveniment d&apos;arrencada-aturada</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Registre de dnf</translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Interval de refresc</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 segons</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 min</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>5 min</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Sense refresc</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Exporta-ho tot</translation>
    </message>
    <message>
        <source>System Logs</source>
        <translation>Registres del sistema</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Refresca-ho ara</translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.5.10+ds1.orig.tar.xz: deepin-log-viewer-6.5.10/translations/deepin-log-viewer_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ca">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Mostra al gestor de fitxers</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Esborra el registre</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Actualitza</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Segur que voleu esborrar el registre?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Confirmeu-ho</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Tots</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Avui</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 dies</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 setmana</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 mes</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 mesos</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exporta</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Tots</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Emergència</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alerta</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Crític</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Avís</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Observació</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informació</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Depuració</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Entrada</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Arrencada</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Atura</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Molt crític</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Traça</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation>Autenticació de la identiitat</translation>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation>Control d&apos;accés discrecional</translation>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation>Control d&apos;accés obligatori</translation>
    </message>
    <message>
        <source>Remote</source>
        <translation>Remot</translation>
    </message>
    <message>
        <source>Document audit</source>
        <translation>Auditoria de documents</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Altres</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation>zip (*.zip)</translation>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>S&apos;exporta...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Exportació correcta</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Ha fallat l&apos;exportació.</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation>El directori d&apos;exportació no està disponible. Si us plau, trieu un altre directori per a l&apos;operació d&apos;exportació.</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Exporta el fitxer</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Període:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Nivell:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Estat:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Tipus d&apos;esdeveniment:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Usuari:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Acció:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nom d&apos;usuari:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Registre d&apos;arrencada</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Historial d&apos;aturada</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Historial d&apos;entrada</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation>Tipus d&apos;auditoria:</translation>
    </message>
    <message>
        <source>Application:</source>
        <translation>Aplicació:</translation>
    </message>
    <message>
        <source>Submodule:</source>
        <translation>Submòdul:</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Avís</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Depuració</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informació</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Emergència</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alerta</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Crític</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Observació</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Traça</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Molt crític</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>El fitxer de registre és buit.</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Visor de registres</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>El Visor de registres és una eina útil per veure els registres del sistema.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>No hi ha resultats de cerca</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Cerca</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Nivell</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Procés</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Data i hora</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Informació</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Usuari</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Font</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Acció</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Estat</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Tipus d&apos;esdeveniment</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nom d&apos;usuari</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Nivell:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Procés:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Dia i hora:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Informació:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Nul</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Usuari:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>Nom del fitxer</translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation>Hora de modificació</translation>
    </message>
    <message>
        <source>SIG</source>
        <translation>SIG</translation>
    </message>
    <message>
        <source>EXE</source>
        <translation>EXE</translation>
    </message>
    <message>
        <source>Core File</source>
        <translation>Fitxer de nucli</translation>
    </message>
    <message>
        <source>User Name </source>
        <translation>Nom d&apos;usuari</translation>
    </message>
    <message>
        <source>Offset</source>
        <translation>Forani</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Data i hora</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Registre del sistema</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Registre del nucli</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Registre d&apos;arrencada</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Registre del dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Registre de Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Registre del Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Registre d&apos;aplicacions</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Esdeveniment d&apos;arrencada-aturada</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Registre de dnf</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation>Altres registres</translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation>Registre personalitzat</translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation>Registre d&apos;auditoria</translation>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation>Registre d&apos;abocament del nucli</translation>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation>No es pot obtenir la informació de l&apos;error. Instal·leu systemd-coredump.</translation>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation>No teniu permís per veure-ho.</translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation>Nivell de seguretat del sistema actual: alt
Només els administradors poden veure el registre d&apos;auditoria.</translation>
    </message>
    <message>
        <source>Audit log is not exist.</source>
        <translation>El registre d&apos;auditoria no existeix.</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation>Exporta els registres al camí especificat</translation>
    </message>
    <message>
        <source>PATH</source>
        <translation>CAMÍ</translation>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation>Exporta registres dels tipus especificats</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>TIPUS</translation>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation>Exporta els registres d&apos;aplicacions de desenvolupament propi especificades</translation>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation>NOM DE L&apos;APLICACIÓ PRÒPIA</translation>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation>Exporta els registres d&apos;un període de temps especificat</translation>
    </message>
    <message>
        <source>PERIOD</source>
        <translation>PERÍODE</translation>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation>Exporta els registres dins d&apos;un nivell de depuració especificat.</translation>
    </message>
    <message>
        <source>LEVEL</source>
        <translation>NIVELL</translation>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation>ESTAT D&apos;ARRENCADA</translation>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation>Exporta els registres d&apos;arrencada (no-klu) d&apos;un estat especificat</translation>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation>Exporta registres d&apos;esdeveniments d&apos;apagada, d&apos;arrencada o d&apos;auditoria d&apos;un tipus d&apos;esdeveniment especificat</translation>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation>TIPUS D&apos;ESDEVENIMENT</translation>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation>Exporta els registres basats en els resultats de la cerca de paraules clau</translation>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation>PARAULA CLAU</translation>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation>Comunica la informació d&apos;abocament.</translation>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation>Exporta registres basats en el submodel d&apos;aplicació</translation>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation>SUBMÒDUL</translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Interval de refresc</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 segons</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 min</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>5 min</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Sense refresc</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Exporta-ho tot</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Refresca-ho ara</translation>
    </message>
</context>
</TS>
